==> photoupload.6.4.6.592.zip: photoupload.lrplugin/NPPTar.lua <==
LuaQ     @..\common\NPPTar.lua              
   E   @  \                     	A                  	          require 
   NPPLogger 
   NPPUtilities 
   resetTarFile    tarFile        %   +            @ @ @  A   D   F   @ A D   \@B   H          logOutputFunctionName    require 
   NPPUtilities 
   logOutput    INFO 
   Old value =     valueToString        &   &   &   (   (   (   )   )   )   )   )   )   )   )   )   *   *   +      
   NPPUtilities          
   NPPLogger 	   _tarFile    _tarFileChecked     /   [    M   D   F  \@ C  A  @ EA  Z  @       E A \     FA \ B @     C      @        B@ CC   C ܃   B@ CC       D      @          logOutputFunctionName    WIN_ENV    tar.exe    tar    require 
   NPPPlugin 
   NPPConfig #   configurationSettingValueOrDefault %   configurationExternalBinaryFilesPath 
   --version    findExternalBinaryFile    stringTrimRight    string    char       *@      $@    M   0   0   0   2   6   6   6   7   8   8   8   9   9   ;   =   =   =   >   >   >   ?   A   A   A   B   C   D   D   D   D   D   D   D   D   D   D   E   E   F   F   H   J   J   L   L   L   L   L   L   L   L   L   L   L   L   L   L   M   M   M   M   M   M   M   M   M   O   Q   Q   U   V   W   Z   Z   Z   Z   [         taskID     L      tarFilePathWithName    L   
   errorMessage    L      tarVersion    L   	   fileName    E   
   NPPPlugin    E   
   NPPConfig    E      ok    E      filePathWithName    E      configurationPath    E      fileCommandLineArguments    E      commandLineOutput    E      
   NPPLogger    _tarFileChecked 	   _tarFile    _tarFileErrorMessage 
   NPPUtilities    _tarVersion                               +   +   +   +   %   [   [   [   [   [   [   [   /   _   _         NPPTar       
   NPPLogger       
   NPPUtilities          _tarFileChecked       	   _tarFile 	         _tarFileErrorMessage 	         _tarVersion 	          

==> photoupload.6.4.7.667.zip: photoupload.lrplugin/NPPTar.lua <==
LuaQ     @..\common\NPPTar.lua              
   E   @  \                     	A                  	          require 
   NPPLogger 
   NPPUtilities 
   resetTarFile    tarFile        %   +            @ @ @  A   D   F   @  \@ B   H          logOutputFunctionName    require 
   NPPUtilities 
   logOutput    INFO 
   Old value =         &   &   &   (   (   (   )   )   )   )   )   )   *   *   +      
   NPPUtilities          
   NPPLogger 	   _tarFile    _tarFileChecked     /   [    M   D   F  \@ C  A  @ EA  Z  @       E A \     FA \ B @     C      @        B@ CC   C ܃   B@ CC       D      @          logOutputFunctionName    WIN_ENV    tar.exe    tar    require 
   NPPPlugin 
   NPPConfig #   configurationSettingValueOrDefault %   configurationExternalBinaryFilesPath 
   --version    findExternalBinaryFile    stringTrimRight    string    char       *@      $@    M   0   0   0   2   6   6   6   7   8   8   8   9   9   ;   =   =   =   >   >   >   ?   A   A   A   B   C   D   D   D   D   D   D   D   D   D   D   E   E   F   F   H   J   J   L   L   L   L   L   L   L   L   L   L   L   L   L   L   M   M   M   M   M   M   M   M   M   O   Q   Q   U   V   W   Z   Z   Z   Z   [         taskID     L      tarFilePathWithName    L   
   errorMessage    L      tarVersion    L   	   fileName    E   
   NPPPlugin    E   
   NPPConfig    E      ok    E      filePathWithName    E      configurationPath    E      fileCommandLineArguments    E      commandLineOutput    E      
   NPPLogger    _tarFileChecked 	   _tarFile    _tarFileErrorMessage 
   NPPUtilities    _tarVersion                               +   +   +   +   %   [   [   [   [   [   [   [   /   _   _         NPPTar       
   NPPLogger       
   NPPUtilities          _tarFileChecked       	   _tarFile 	         _tarFileErrorMessage 	         _tarVersion 	          
